pub enum EntityState {
Unchanged,
Added,
Modified,
Deleted,
}Expand description
Lifecycle state for a tracked entity.
Variants
Unchanged
Entity was loaded and has not requested mutable access.
Added
Entity was added locally and should be inserted by save_changes().
Modified
Entity was loaded and then mutably accessed.
Deleted
Entity was explicitly marked for deletion.