pub fn model_snapshot_from_source<S: MigrationModelSource>() -> ModelSnapshotExpand description
Builds a model snapshot from a context type that exposes entity metadata.
This is the helper used by consumer snapshot-export binaries.
pub fn model_snapshot_from_source<S: MigrationModelSource>() -> ModelSnapshotBuilds a model snapshot from a context type that exposes entity metadata.
This is the helper used by consumer snapshot-export binaries.