pub struct Collection<T> { /* private fields */ }Expand description
Marker value for a collection navigation.
Collection navigation fields are ignored by column metadata and start empty when an entity is materialized without an explicit include/load operation.
Implementations