DbSetGroupedQuery

Struct DbSetGroupedQuery 

pub struct DbSetGroupedQuery<E: Entity> { /* private fields */ }
Query builder returned by DbSetQuery::group_by(...).

Implementations

Source

impl<E: Entity> DbSetGroupedQuery<E>

pub fn select_aggregate<P>(self, projection: P) -> Self

Selects aggregate projections materialized by alias into DTOs.

pub fn try_select_aggregate<P>(self, projection: P) -> Result<Self, OrmError>

Selects aggregate projections and validates aliases before execution.

pub fn having(self, predicate: AggregatePredicate) -> Self

Adds a HAVING predicate over aggregate expressions or group keys.

pub fn order_by(self, order: AggregateOrderBy) -> Self

Adds aggregate ordering.

pub fn limit(self, limit: u64) -> Self

Limits grouped aggregate rows with zero offset.

pub fn take(self, limit: u64) -> Self

Alias for limit(...).

pub fn paginate(self, request: PageRequest) -> Self

Applies page-based pagination to grouped aggregate rows.

pub async fn all_as<T>(self) -> Result<Vec<T>, OrmError>
where T: FromRow + Send,

Executes the grouped query and materializes projected rows as DTOs.

pub async fn first_as<T>(self) -> Result<Option<T>, OrmError>
where T: FromRow + Send,

Executes the grouped query and materializes the first DTO, if any.