AggregateProjections

Trait AggregateProjections 

pub trait AggregateProjections {
    // Required method
    fn into_aggregate_projections(self) -> Vec<AggregateProjection>;
}
Converts public select_aggregate(...) arguments into aggregate projections.

Required Methods

Implementations on Foreign Types

Source

impl<A> AggregateProjections for (A,)

Source

impl<A, B> AggregateProjections for (A, B)

Source

impl<A, B, C> AggregateProjections for (A, B, C)

Source

impl<A, B, C, D> AggregateProjections for (A, B, C, D)

Source

impl<A, B, C, D, E> AggregateProjections for (A, B, C, D, E)

Source

impl<A, B, C, D, E, F> AggregateProjections for (A, B, C, D, E, F)

Source

impl<A, B, C, D, E, F, G> AggregateProjections for (A, B, C, D, E, F, G)

Source

impl<A, B, C, D, E, F, G, H> AggregateProjections for (A, B, C, D, E, F, G, H)

Source

impl<A, B, C, D, E, F, G, H, I> AggregateProjections for (A, B, C, D, E, F, G, H, I)

Source

impl<A, B, C, D, E, F, G, H, I, J> AggregateProjections for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A, B, C, D, E, F, G, H, I, J, K> AggregateProjections for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> AggregateProjections for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<P> AggregateProjections for Vec<P>

Source

impl<P, const N: usize> AggregateProjections for [P; N]

Implementors