IncludeNavigation

Trait IncludeNavigation 

pub trait IncludeNavigation<T>: Entity {
    // Required method
    fn set_included_navigation(
        &mut self,
        navigation: &str,
        value: Option<T>,
    ) -> Result<(), OrmError>;
}
Contract generated for entities that can receive an included single navigation value.

This is used by DbSetQuery::include::<T>(...) for belongs_to and has_one navigations. Collection includes use a different loading strategy and are intentionally not part of this contract.

Required Methods

fn set_included_navigation( &mut self, navigation: &str, value: Option<T>, ) -> Result<(), OrmError>

Attaches a loaded navigation value to the field named by navigation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors