MigrationModelSource

Trait MigrationModelSource 

pub trait MigrationModelSource {
    // Required method
    fn entity_metadata() -> &'static [&'static EntityMetadata];
}
Provides entity metadata for code-first migration snapshot generation.

#[derive(DbContext)] implements this trait for application contexts by returning the metadata for every DbSet<T> declared on the context.

Required Methods

fn entity_metadata() -> &'static [&'static EntityMetadata]

Returns the static metadata for all entities owned by the context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors