SelectProjections

Trait SelectProjections 

pub trait SelectProjections {
    // Required method
    fn into_select_projections(self) -> Vec<SelectProjection>;
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SelectProjections for Expr

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> SelectProjections for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<A, B, C, D, E, F, G, H, I, J, K> SelectProjections for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A, B, C, D, E, F, G, H, I, J> SelectProjections for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A, B, C, D, E, F, G, H, I> SelectProjections for (A, B, C, D, E, F, G, H, I)

Source

impl<A, B, C, D, E, F, G, H> SelectProjections for (A, B, C, D, E, F, G, H)

Source

impl<A, B, C, D, E, F, G> SelectProjections for (A, B, C, D, E, F, G)

Source

impl<A, B, C, D, E, F> SelectProjections for (A, B, C, D, E, F)

Source

impl<A, B, C, D, E> SelectProjections for (A, B, C, D, E)

Source

impl<A, B, C, D> SelectProjections for (A, B, C, D)

Source

impl<A, B, C> SelectProjections for (A, B, C)

Source

impl<A, B> SelectProjections for (A, B)

Source

impl<A> SelectProjections for (A,)

Source

impl<P, const N: usize> SelectProjections for [P; N]

Source

impl<P> SelectProjections for Vec<P>

Implementors