EntityState

Enum EntityState 

pub enum EntityState {
    Unchanged,
    Added,
    Modified,
    Deleted,
}
Lifecycle state for an experimentally tracked entity.

Variants



Unchanged

Entity was loaded and has not requested mutable access.



Added

Entity was added locally and should be inserted by save_changes().



Modified

Entity was loaded and then mutably accessed.



Deleted

Entity was explicitly marked for deletion.