RawParam

Trait RawParam 

pub trait RawParam {
    // Required method
    fn into_sql_value(self) -> SqlValue;
}
Converts one raw SQL parameter into an ORM SqlValue.

Raw SQL placeholders are positional and must be written as @P1, @P2, and so on. Reusing the same placeholder index reuses the same parameter value.

Required Methods

fn into_sql_value(self) -> SqlValue

Converts this value into a SQL Server parameter value.

Implementations on Foreign Types

Source

impl RawParam for &str

Source

impl RawParam for bool

Source

impl RawParam for f64

Source

impl RawParam for i32

Source

impl RawParam for i64

Source

impl RawParam for String

Source

impl RawParam for Vec<u8>

Source

impl RawParam for NaiveDate

Source

impl RawParam for NaiveDateTime

Source

impl RawParam for Decimal

Source

impl RawParam for Uuid

Source

impl<T> RawParam for Option<T>
where T: RawParam,

Implementors