pub trait RawParam {
// Required method
fn into_sql_value(self) -> SqlValue;
}Expand description
Converts one raw SQL parameter into an ORM SqlValue.
Raw SQL placeholders are positional and must be written as @P1, @P2,
and so on. Reusing the same placeholder index reuses the same parameter
value.
Required Methods
Sourcefn into_sql_value(self) -> SqlValue
fn into_sql_value(self) -> SqlValue
Converts this value into a SQL Server parameter value.